#!/usr/bin/env python

"""Build this package by self.

This file is only for rez to build the package.
"""

# Import build-in modules
import os
import sys

sys.path.insert(
    0, os.path.join(os.path.dirname(os.path.abspath(__file__)), "src"))

# Import third-party modules
from rezbuild.builder import PythonSourceBuilder


if __name__ == '__main__':
    PythonSourceBuilder().build(use_venv=False)



"""Utilities for rez_builder."""

# Import built-in modules
import os
import platform
import shutil
import stat


def clear_path(path):
    """Remove all the files and directories under the path.

    Args:
        path (str): The path to clear.
    """
    if os.path.isdir(path):
        shutil.rmtree(path)
    os.makedirs(path)


def get_delimiter():
    """Get the system delimiter of the path.

    Returns:
        str: The path delimiter for the system.
    """
    if platform.system() == "Windows":
        return ";"
    else:
        return ":"


def get_relative_path(from_path, to_path):
    """Get the relative path between two paths.

    Args:
        from_path (str): The path where the relative path from.
        to_path (str): The path where the relative path to.
    """
    from_path = from_path.replace("\\", "/")
    to_path = to_path.replace("\\", "/")
    folders1, folders2 = from_path.split("/"), to_path.split("/")
    length = min(len(folders1), len(folders2))
    for i in range(length):
        folder1, folder2 = folders1[i], folders2[i]
        if folder1 != folder2:
            length = i
            break
    return "/".join(['..'] * (len(folders1) - length) + folders2[length:])


def remove_tree(path):
    """Remove directory.

    Args:
        path (str): The directory to remove.
    """
    def rm_readonly(func, path_, _):
        """Remove read-only files on Windows.

        Reference from https://stackoverflow.com/questions/1889597 and
        https://github.com/ansible/ansible/issues/34335

        Args:
            func (function): Function which will remove the file/folder.
            path_ (str): Path to file/folder which should be removed.
        """
        os.chmod(path_, stat.S_IWRITE)
        func(path_)

    shutil.rmtree(path, onerror=rm_readonly)



# -*- coding: utf-8 -*-

name = "rezbuild"

tools = []

variants = []

requires = [
    "build-0.3+",
    "pip-18+",
    "python-3.8+<4",
]

private_build_requires = [
    "git",
    "setuptools-42+",
    "setuptools_scm-3.4+",
    "wheel",
]

build_command = "python {root}/build.py {install}"


def commands():
    env.PYTHONPATH.append("{root}/site-packages")


@early()
def version():
    import os
    import platform
    import sys
    from rez.resolved_context import ResolvedContext
    context = ResolvedContext(["setuptools_scm", "git"])
    if platform.system() == "Windows":
        delimiter = ";"
    else:
        delimiter = ":"
    paths = context.get_environ()["PATH"].split(delimiter)
    pythonpaths = context.get_environ()["PYTHONPATH"].split(delimiter)
    os.environ["PATH"] = delimiter.join(paths)
    sys.path.extend(pythonpaths)
    from setuptools_scm import get_version
    return get_version()
